<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk_UA">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Оберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
</context>
<context>
    <name>QvkCameraSettingsDialog</name>
    <message>
        <source>Camera settings</source>
        <translation>Налаштування камери</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Перевернути</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Перемикнутися на режим вікна</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Перемикнутися на повний екран</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Перемикнутися на режим вікна</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Перемикнутися на повний екран</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Налаштування пройшло успішно.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Закрийте це вікно та знову запустіть vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Розважайтеся з vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Діалогове вікно</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Оберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Не знайдено файлового менеджера</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Будь ласка, встановіть файловий менеджер.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Запис не почато, бракує вільного місця на диску.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Досягнуто ліміту вільного місця на диску. </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ліміт вільного місця на диску</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Запис зупинено, бракує вільного місця на диску. </translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Файлового упорядника не знайдено.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Будь ласка встановіть файловий упорядник.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Джерельний код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Вебсайт</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Джерельний код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Вебсайт</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Оберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Файлового упорядника не знайдено.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Будь ласка встановіть файловий упорядник.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Оберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Діалогове вікно</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Перевернути</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Налаштування камери</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Зворотній відлік</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Розмір відеофайлу: </translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Вільне місце на диску: </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Час запису:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадри</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Відеокодек</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Авдіокодек</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записувати вказівник миші</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Година</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Хвилина</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Запустити таймер</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Зупинити запис через</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Години</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Хвилини</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунди</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Зберегти до теки</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ліміт вільного місця на диску</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показати значок на панелі</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Зачекати секунд перед початком запису</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Перевірити оновлення</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступний</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступний</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Тека</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Перевернути</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Відтворити останній запис</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Згортати вікно при початку запису</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Запускати згорнутим</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Скинути усі налаштування при наступному старті</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Скрінкаст</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Програвач</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Лог</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Створення зображень вкладок</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Інформація про ліцензію</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>УВІМК</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>ВИМК</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Глобальні клавішні скорочення</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Призначені клавіші швидкого доступу.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Скорочення клавішів не призначено або призначено більше одного разу.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Якщо показує призначено, але не працює, то використовується іншою програмою.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Знімок</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Шлях до зображення</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Згорнути це вікно</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Зачекати секунду перед записуванням</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Увесь екран</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Створення зображень вкладок</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Інформація про ліцензію</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>УВІМК</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>ВИМК</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Час запису:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Розмір відеофайлу: </translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Вільне місце на диску: </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Увесь екран</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Відеокодек</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадри</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступний</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступний</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Тека</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записувати вказівник миші</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
</context>
</TS>